# An example of how to use the regina API to traverse the given
# regina files.

import regina

def children_iterator(packet):
    """
    Iterate through all the children of a regina packet.
    """
    child = packet.getFirstTreeChild()
    while child:
        yield child
        child = child.getNextTreeSibling()

def find_recursive(packet, name):
    """
    Search a regina packet recursively for a node
    of the given name.
    """
    for child in children_iterator(packet):
        if child.getPacketLabel() == name:
            return child
        ancestor = find_recursive(child, name)
        if ancestor:
            return ancestor

if __name__ == '__main__':
    
    # Open the packet
    packet = regina.open('tetrahedralOrientableCuspedCensus.rga')
    # Find the container for otet08_0002
    container = find_recursive(packet, 'otet08_0002')
    # Get all the items from that container
    items = list(children_iterator(container))
    # All but the last item are the combinatorial tetrahedral
    # tessellations of otet08_0002
    tessellations = items[:-1]
    # The last item is the canonical retriangulation
    canonicalRetriangulation = items[-1]

    print 'otet08_0002 has the following combinatorial tessellations:'

    for tessellation in tessellations:
        print '    ', tessellation.getPacketLabel(),
        print '(isomorphism signature: %s)' % tessellation.isoSig()

    print 'Its isometry signature is:',
    print canonicalRetriangulation.isoSig()
    
